%define module	pyzmq


# disable test on BS, but ok on local iurt
%global run_tests 0

Summary:	Python bindings for zeromq
Name:		python-%{module}
Version:	15.2.0
Release:	%mkrel 2
Source0:	https://pypi.python.org/packages/source/p/%{module}/%{module}-%{version}.tar.gz
License:	LGPLv3+ and ASL 2.0 and BSD
Group:		Development/Python
Url:		http://github.com/zeromq/pyzmq
BuildRequires:  chrpath
BuildRequires:	pkgconfig(libzmq)
BuildRequires:	python-nose
BuildRequires:	python-setuptools
BuildRequires:	pkgconfig(python)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools
BuildRequires:	python3-nose
BuildRequires:	python-tools
BuildRequires:	python-cython

# test
%if 0%{?run_tests}
BuildRequires:  python3-tornado
%endif

%description
This package contains Python bindings for zeromq, a lightweight and
fast messaging implementation.

%package -n python3-%{module}
Summary:        Software library for fast, message-based applications
Group:          Development/Python

%description -n python3-%{module}
The 0MQ lightweight messaging kernel is a library which extends the
standard socket interfaces with features traditionally provided by
specialized messaging middle-ware products. 0MQ sockets provide an
abstraction of asynchronous message queues, multiple messaging
patterns, message filtering (subscriptions), seamless access to
multiple transport protocols and more.

This package contains the python 3 bindings.

%prep
%setup -q -n %{module}-%{version}

# remove bundled libraries
rm -rf bundled
for lib in zmq/eventloop/*.py; do
    sed '/\/usr\/bin\/env/d' $lib > $lib.new &&
    touch -r $lib $lib.new &&
    mv $lib.new $lib
done

# remove excecutable bits
chmod -x examples/pubsub/topics_pub.py
chmod -x examples/pubsub/topics_sub.py

%build
%{py3_build}
%{py2_build}

%install
%global RPATH /zmq/{backend/cython,devices}
%{py3_install}
chrpath --delete %{buildroot}%{python3_sitearch}%{RPATH}/*.so
%{py2_install}
chrpath --delete %{buildroot}%{python2_sitearch}%{RPATH}/*.so
%{__rm} -f %{buildroot}%{python2_sitearch}/zmq/tests/_test_asyncio.py  
%{__rm} -f %{buildroot}%{python2_sitearch}/zmq/tests/test_asyncio.py
%{__rm} -f %{buildroot}%{python2_sitearch}/zmq/asyncio.py
%{__rm} -f %{buildroot}%{python2_sitearch}/zmq/auth/asyncio.py

%check
%if 0%{?run_tests}
   %{__rm} -f zmq/__*
   PYTHONPATH=%{buildroot}%{python3_sitearch} \
    %{__python3} setup.py test
   %{__rm} -rf %{buildroot}%{python2_sitearch}/zmq/tests
   %{__rm} -rf %{buildroot}%{python3_sitearch}/zmq/tests
%endif

%files
%doc README.md COPYING.* examples/
%{python2_sitearch}/%{module}-*.egg-info
%{python2_sitearch}/zmq

%files -n python3-%{module}
%doc README.md COPYING.*
# examples/
%{python3_sitearch}/%{module}-*.egg-info
%{python3_sitearch}/zmq


%changelog
* Sat Mar 05 2016 philippem <philippem> 15.2.0-2.mga6
+ Revision: 986119
- update sources to 15.2.0, clean spec
- update to 15.2.0, disable test on BS

* Tue Feb 16 2016 umeabot <umeabot> 15.0.0-3.mga6
+ Revision: 962422
- Mageia 6 Mass Rebuild

* Wed Nov 18 2015 joequant <joequant> 15.0.0-2.mga6
+ Revision: 903951
- upgrade to 15.0.0

* Wed Oct 07 2015 philippem <philippem> 14.7.0-2.mga6
+ Revision: 887170
- rebuild for Python3.5

* Wed Aug 19 2015 joequant <joequant> 14.7.0-1.mga6
+ Revision: 865836
- upgrade to 14.7.0

* Wed Aug 19 2015 joequant <joequant> 14.3.1-6.mga6
+ Revision: 865827
- update to libpyzmq5

* Mon Nov 17 2014 barjac <barjac> 14.3.1-5.mga5
+ Revision: 797628
- rebuild for new zeromq

* Wed Oct 15 2014 umeabot <umeabot> 14.3.1-4.mga5
+ Revision: 749943
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 14.3.1-3.mga5
+ Revision: 729613
- rebuild for missing pythoneggs deps

  + umeabot <umeabot>
    - Mageia 5 Mass Rebuild

* Wed Jul 30 2014 barjac <barjac> 14.3.1-1.mga5
+ Revision: 658114
-new version 14.3.1
- rebuild for new zeromq-4.0.4

* Mon Jun 02 2014 philippem <philippem> 14.3.0-1.mga5
+ Revision: 630651
- update to 14.3.0

  + pterjan <pterjan>
    - Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 13.1.0-3.mga4
+ Revision: 544242
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 13.1.0-2.mga4
+ Revision: 499281
- Rebuild to add different pythonegg provides for python 2 and 3

* Fri Aug 16 2013 philippem <philippem> 13.1.0-1.mga4
+ Revision: 467030
- fix wrong group
- update to 13.1.0, add Python 3

* Sat Jun 08 2013 fwang <fwang> 2.2.0.1-2.mga4
+ Revision: 440438
- drop invalid req

* Sat Jun 08 2013 fwang <fwang> 2.2.0.1-1.mga4
+ Revision: 440417
- add req for testing
- new version 2.2.0.1

* Sun Jan 13 2013 umeabot <umeabot> 2.1.9-4.mga3
+ Revision: 379424
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Sep 21 2011 lebedov <lebedov> 2.1.9-3.mga2
+ Revision: 146196
- Bump release.

* Wed Sep 21 2011 lebedov <lebedov> 2.1.9-2.mga2
+ Revision: 146188
- Require zeromq library with the same version as pyzmq (or later).

* Sun Sep 18 2011 lebedov <lebedov> 2.1.9-1.mga2
+ Revision: 145119
- Update source file.
- Update to 2.1.9.

* Thu Apr 14 2011 mikala <mikala> 2.1.4-1.mga1
+ Revision: 85343
- Update to 2.1.4 to match zeromq 2.1.4

* Mon Jan 31 2011 dmorgan <dmorgan> 2.0.10_1-1.mga1
+ Revision: 45303
- imported package python-pyzmq

